{{- define "drupal.containers" -}}
{{- if ne (len .) 2 -}}
  {{ required "drupal.containers define expects 2 arguments!" }}
{{- end -}}
{{- $mode := index . 1 -}}
{{- with index . 0 -}}
volumes:
  - name: settings-infra
    configMap:
      name: {{ include "drupal.fullname" . }}
  {{- with .Values.volumes }}
    {{- toYaml . | nindent 10 }}
  {{- end }}
containers:
  - name: {{ .Chart.Name }}
    securityContext:
      {{- toYaml .Values.securityContext | nindent 6 }}
    image: "{{ .Values.image.repository }}:{{ .Values.image.tag | default .Chart.AppVersion }}"
    imagePullPolicy: {{ .Values.image.pullPolicy }}
    env:
      - name: DEPLOYMENT_IDENTIFIER
        value: {{ .Values.image.tag }}
      - name: BOOTSTRAP_CMD
        valueFrom:
          configMapKeyRef:
            name: {{ include "drupal.fullname" . }}
            key: drupal-bootstrap-cmd
      - name: APP_NAME
        valueFrom:
          configMapKeyRef:
            name: {{ include "drupal.fullname" . }}
            key: drupal-app-name
      - name: APP_ENV
        valueFrom:
          configMapKeyRef:
            name: {{ include "drupal.fullname" . }}
            key: drupal-app-env
      - name: APP_DOMAIN
        valueFrom:
          configMapKeyRef:
            name: {{ include "drupal.fullname" . }}
            key: drupal-app-domain
            optional: true
      - name: DB_HOST
        valueFrom:
          configMapKeyRef:
            name: {{ include "drupal.fullname" . }}
            key: drupal-db-host
      - name: DB_PORT
        valueFrom:
          configMapKeyRef:
            name: {{ include "drupal.fullname" . }}
            key: drupal-db-port
            optional: true
      - name: DB_NAME
        valueFrom:
          configMapKeyRef:
            name: {{ include "drupal.fullname" . }}
            key: drupal-db-name
      - name: DB_USER
        valueFrom:
          configMapKeyRef:
            name: {{ include "drupal.fullname" . }}
            key: drupal-db-user
      - name: REDIS_ENABLED
        valueFrom:
          configMapKeyRef:
            name: {{ include "drupal.fullname" . }}
            key: drupal-redis-enabled
            optional: true
      - name: REDIS_HOST
        valueFrom:
          configMapKeyRef:
            name: {{ include "drupal.fullname" . }}
            key: drupal-redis-host
            optional: true
      - name: REDIS_PORT
        valueFrom:
          configMapKeyRef:
            name: {{ include "drupal.fullname" . }}
            key: drupal-redis-port
            optional: true
      - name: DRUPAL_TRUSTED_HOST_PATTERNS
        valueFrom:
          configMapKeyRef:
            name: {{ include "drupal.fullname" . }}
            key: drupal-trusted-host-patterns
            optional: true
      - name: DB_PASS
        valueFrom:
          secretKeyRef:
            name: {{ include "drupal.fullname" . }}
            key: drupal-db-pass
      - name: DRUPAL_HASH_SALT
        valueFrom:
          secretKeyRef:
            name: {{ include "drupal.fullname" . }}
            key: drupal-hash-salt
    {{- include "drupal.podEnv" (list .Values.commonEnvs .Values.drupal.envs) | nindent 6 -}}
    {{- if eq $mode "svc" }}
    ports:
      - name: http
        containerPort: {{ .Values.service.port }}
        protocol: TCP
    {{- if .Values.livenessProbe.enabled }}
    livenessProbe:
      httpGet:
        path: {{ .Values.livenessProbe.path }}
        port: http
      initialDelaySeconds: {{ .Values.livenessProbe.initialDelaySeconds }}
      periodSeconds: {{ .Values.livenessProbe.periodSeconds }}
      timeoutSeconds: {{ .Values.livenessProbe.timeoutSeconds }}
      successThreshold: {{ .Values.livenessProbe.successThreshold }}
      failureThreshold: {{ .Values.livenessProbe.failureThreshold }}
    {{- else if .Values.customLivenessProbe }}
    livenessProbe: {{- include "common.tplvalues.render" (dict "value" .Values.customLivenessProbe "context" .) | nindent 6 -}}
    {{- end }}
    {{- if .Values.readinessProbe.enabled }}
    readinessProbe:
      httpGet:
        path: {{ .Values.readinessProbe.path }}
        port: http
      initialDelaySeconds: {{ .Values.readinessProbe.initialDelaySeconds }}
      periodSeconds: {{ .Values.readinessProbe.periodSeconds }}
      timeoutSeconds: {{ .Values.readinessProbe.timeoutSeconds }}
      successThreshold: {{ .Values.readinessProbe.successThreshold }}
      failureThreshold: {{ .Values.readinessProbe.failureThreshold }}
    {{- else if .Values.customReadinessProbe }}
    readinessProbe: {{- include "common.tplvalues.render" (dict "value" .Values.customReadinessProbe "context" .) | nindent 6 -}}
    {{- end }}
    {{- end -}} {{/* if eq $mode "svc" */}}
    volumeMounts:
      - name: settings-infra
        mountPath: "{{ .Values.drupal.docRoot }}/sites/{{ .Values.drupal.siteDir }}/settings.infra.php"
        subPath: settings-infra
      {{- with .Values.volumeMounts }}
        {{- toYaml . | nindent 14 }}
      {{- end }}
{{- end }} {{/* with index */}}
{{- end }} {{/* define */}}
{{/* vim: set filetype=mustache: */}}
