{{- define "drupal.cronjob" -}}
{{- if ne (len .) 3 -}}
  {{ required "drupal.cronjob define expects 3 arguments!" }}
{{- end -}}
{{- $name := index . 1 -}}
{{- $cron := index . 2 -}}
{{- with index . 0 -}}
{{ if semverCompare ">=1.21-0" .Capabilities.KubeVersion.GitVersion -}}
apiVersion: batch/v1
{{- else -}}
apiVersion: batch/v1beta1
{{- end }}
kind: CronJob
metadata:
  name: {{ include "drupal.fullname" . }}-{{ $name }}
  labels:
    {{- include "drupal.labels" . | nindent 4 }}
    app.kubernetes.io/component: {{ $name }}
spec:
  schedule: "{{ $cron.schedule }}"
  suspend: {{ $cron.suspend }}
  concurrencyPolicy: Forbid
  jobTemplate:
    spec:
      template:
        metadata:
          {{- with .Values.podAnnotations }}
          annotations:
            {{- toYaml . | nindent 12 }}
          {{- end }}
          labels:
            {{- include "drupal.labels" . | nindent 12 }}
            {{- with .Values.podLabels }}
            {{- toYaml . | nindent 12 }}
            {{- end }}
            app.kubernetes.io/component: cronjob-{{ $name }}
        spec:
          restartPolicy: Never
          {{- include "drupal.containers" (list . "cron") | nindent 10 }}
              command:
                {{- toYaml $cron.command | nindent 16 }}
              resources:
                {{- merge $cron.resources .Values.resources | toYaml | nindent 16 }}
{{- end }}
{{- end }}
{{/* vim: set filetype=mustache: */}}
